==> 0.0.2+4.tar.gz: lib/presentation/pages/expert_page.dart <==
import 'package:chat_call_core/shared/base/base_state.dart';
import 'package:chat_call_core/shared/di/injector.dart';
import 'package:hainong_expert_module/presentation/pages/expert/expert_list_page.dart';
import '../app/app_bloc.dart';
import '../app/app_event.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

final appBloc = getIt<AppBloc>();

class ExpertPage extends StatefulWidget {
  final bool? isDevelop;

  final Function() callBackContact;

  ExpertPage(
      {required this.callBackContact, Key? key, this.isDevelop = false})
      : super(key: key);
  @override
  State<ExpertPage> createState() => _ExpertPageState();
}

class _ExpertPageState extends State<ExpertPage> {
  final _appBloc = getIt<AppBloc>()..add(Init());

  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    _appBloc.close();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return AnnotatedRegion<SystemUiOverlayStyle>(
      value: const SystemUiOverlayStyle(
        statusBarIconBrightness: Brightness.light,
        statusBarBrightness: Brightness.dark,
      ),
      child: MultiBlocProvider(
          providers: [
            BlocProvider<AppBloc>(create: (context) => _appBloc),
          ],
          child: BlocBuilder<AppBloc, BaseState>(
            bloc: _appBloc,
            builder: (context, state) {
              return ExpertListPage(callBackContact: widget.callBackContact);
            },
          )),
    );
  }
}

==> 0.0.3+11.tar.gz: lib/presentation/pages/expert_page.dart <==
import 'package:chat_call_core/shared/base/base_state.dart';
import 'package:chat_call_core/shared/di/injector.dart';
import 'package:hainong_expert_module/presentation/pages/expert/expert_list_page.dart';
import '../app/app_bloc.dart';
import '../app/app_event.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

final appBloc = getIt<AppBloc>();

class ExpertPage extends StatefulWidget {
  final bool? isDevelop;

  final Function() callBackContact;
  final Function() callBackLogin;

  ExpertPage(
      {required this.callBackContact,
      required this.callBackLogin,
      Key? key,
      this.isDevelop = false})
      : super(key: key);
  @override
  State<ExpertPage> createState() => _ExpertPageState();
}

class _ExpertPageState extends State<ExpertPage> {
  final _appBloc = getIt<AppBloc>()..add(Init());
  bool? isLogin;

  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    _appBloc.close();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return AnnotatedRegion<SystemUiOverlayStyle>(
      value: const SystemUiOverlayStyle(
        statusBarIconBrightness: Brightness.light,
        statusBarBrightness: Brightness.dark,
      ),
      child: MultiBlocProvider(
          providers: [
            BlocProvider<AppBloc>(create: (context) => _appBloc),
          ],
          child: BlocBuilder<AppBloc, BaseState>(
            bloc: _appBloc,
            builder: (context, state) {
              return ExpertListPage(
                callBackContact: widget.callBackContact,
                callBackSignIn: widget.callBackLogin,
              );
            },
          )),
    );
  }
}
